/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2006 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerProxyMBean.java 9450 2006-08-23 12:21:08Z danesa $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.management.monitoring;

import javax.management.MBeanServer;


/**
 * Implements MBean interface for proxy MBeans. A proxy MBean represents a server in
 * the domain on the master server's MBean server.
 * @author Adriana Danes
 */
public interface ServerProxyMBean {

    /**
     * @return maximum number of retries when detecting a broken connection
     */
    int getMaxcheck();

    /**
     * @param maxcheck value for maximum number of retries when detecting a broken connection
     */
    void setMaxcheck(int maxcheck);

    /**
     * Set state to RUNNING
     */
    void startit();
    /**
     * Stop server
     */
    void stopit();

    public void deployModule(String filename);
    public void undeployModule(String filename);
    public void uploadFile(String filename, boolean replaceExisting);
    public void uploadDeployModule(String filename, boolean replaceExisting);

    public String getClusterDaemonName();

    public int getAllThreadsCount();

    public int getBusyMaxJCAConnection();

    public int getBusyMinJCAConnection();

    public long getBytesReceivedByConnectorTomcat();

    public long getBytesSentByConnectorTomcat();

    public int getConnectionFailuresJCAConnection();

    public int getConnectionLeaksJCAConnection();

    public int getCurrentBusyJCAConnection();

    public int getCurrentInTxJCAConnection();

    public int getCurrentNumberOfBMP();

    public int getCurrentNumberOfCMP();

    public int getCurrentNumberOfEBInMemory();

    public int getCurrentNumberOfEJB();

    public int getCurrentNumberOfMDB();

    public int getCurrentNumberOfSBF();

    public int getCurrentNumberOfSBFInMemory();

    public int getCurrentNumberOfSBL();

    public int getCurrentNumberOfSBLInMemory();

    public int getCurrentOpenedJCAConnection();

    public int getCurrentThreadBusyByConnectorTomcat();

    public int getCurrentThreadCountByConnectorTomcat();

    public Long getCurrentTotalMemory();

    public Long getCurrentUsedMemory();

    public int getCurrentWaitersJCAConnection();

    public int getCurrentWorkerPoolSize();

    public int getErrorCountByConnectorTomcat();

    public String getHostName();

    public int getInitPoolSizeJCAConnection();

    public String getJavaVendor();

    public String getJavaVersion();

    public int getJmsQueuesNbMsgsDeliverSinceCreation();

    public int getJmsQueuesNbMsgsReceiveSinceCreation();

    public int getJmsQueuesNbMsgsSendToDMQSinceCreation();

    public int getJmsTopicsNbMsgsDeliverSinceCreation();

    public int getJmsTopicsNbMsgsReceiveSinceCreation();

    public int getJmsTopicsNbMsgsSendToDMQSinceCreation();

    public String getJOnASVersion();

    public String getLoadCPU();

    public int getMaxNumberOfEBInMemory();

    public int getMaxNumberOfSBFInMemory();

    public int getMaxNumberOfSBLInMemory();

    public int getMaxThreadsByConnectorTomcat();

    public int getMaxWorkerPoolSize();

    public MBeanServer getMbeanServer();

    public int getMinPoolSizeEB();

    public int getMinPoolSizeSBF();

    public int getMinPoolSizeSBL();

    public int getMinWorkerPoolSize();

    public int getPhysicalConnectionOpenedCountJCAConnection();

    public int getPoolMaxOpentimeJCAConnection();

    public int getPoolMaxSizeJCAConnection();

    public int getPoolMaxWaitersJCAConnection();

    public int getPoolMaxWaitTimeJCAConnection();

    public int getPoolMinSizeJCAConnection();

    public int getPoolSizeEB();

    public int getPoolSizeSBF();

    public int getPoolSizeSBL();

    public long getProcessingTimeByConnectorTomcat();

    public String getProtocols();

    public int getPstmtMaxJCAConnection();

    public int getRejectedFullJCAConnection();

    public int getRejectedOpenJCAConnection();

    public int getRejectedOtherJCAConnection();

    public int getRejectedTimeoutJCAConnection();

    public int getRequestCountByConnectorTomcat();

    /**
     * @return the server's state as known by the proxy
     */
    String getState();

    public int getTotalBegunTransactions();

    public int getTotalCommittedTransactions();

    public int getTotalCurrentTransactions();

    public int getTotalExpiredTransactions();

    public int getTotalRolledbackTransactions();

    public int getWaiterCountJCAConnection();

    public int getWaitersHighJCAConnection();

    public int getWaitersHighRecentJCAConnection();

    public int getWaitingHighJCAConnection();

    public int getWaitingHighRecentJCAConnection();

    public int getWaitingTimeJCAConnection();

    public int getXaServedOpenJCAConnection();

    public String getObjectName();

}